.. automodule:: guiqwt

.. only:: html and not htmlhelp

	.. note::

		Windows users may download the :download:`CHM Manual <../guiqwt.chm.zip>`.

		After downloading this file, you may see blank pages in the documentation. 
		That's because Windows is blocking CHM files for security reasons. 
		Fixing this problem is easy:

			* Right-click the CHM file, select properties, then click “Unblock”.
			* Or compress the CHM file into a zip archive and decompress it in 
			  another directory.
			* Do not open the CHM file on a network drive.

Contents:

.. toctree::
    :maxdepth: 2
    
    overview
    installation
    migrating_from_v2_to_v3
    examples
    sift
    disthelpers
    reference/index
    development
    

Indices and tables:

* :ref:`genindex`
* :ref:`search`
